@@ -5,13 +5,12 @@ distribution = setRefClass("distribution",
                              xmin = "ANY", 
                              pars="ANY",
                              no_pars="numeric"))
+
 distribution$accessors(c("xmin", "pars", "dat", "no_pars"))
 
+discrete_distribution = setRefClass("discrete_distribution", contains="distribution")
 
-discrete_distribution = setRefClass("discrete_distribution", 
-                                    contains="distribution")
-ctn_distribution = setRefClass("ctn_distribution", 
-                               contains="distribution")
+ctn_distribution = setRefClass("ctn_distribution", contains="distribution")
 
 
 
